==> Gateway-0.8-sources.jar: org/piangles/gateway/requests/processors/UpdateUserPreferencesRequestProcessor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
 
 
 
package org.piangles.gateway.requests.processors;

import java.util.Map;

import org.piangles.backbone.services.Locator;
import org.piangles.backbone.services.prefs.UserPreferences;
import org.piangles.backbone.services.prefs.UserPreferencesService;
import org.piangles.core.util.reflect.TypeToken;
import org.piangles.gateway.client.ClientDetails;
import org.piangles.gateway.requests.Endpoints;
import org.piangles.gateway.requests.dto.Request;
import org.piangles.gateway.requests.dto.SimpleResponse;

public class UpdateUserPreferencesRequestProcessor extends AbstractRequestProcessor<Map<String, Object>, SimpleResponse>
{
	private UserPreferencesService upService = Locator.getInstance().getUserPreferencesService();
	
	public UpdateUserPreferencesRequestProcessor()
	{
		super(Endpoints.UpdateUserPreferences, new TypeToken<Map<String, Object>>() {}.getActualClass(), SimpleResponse.class);
	}
	
	@Override
	protected SimpleResponse processRequest(ClientDetails clientDetails, Request request, Map<String, Object> nvPair) throws Exception
	{
		UserPreferences prefs = new UserPreferences(clientDetails.getSessionDetails().getUserId(), nvPair);
		
		upService.persistUserPreference(clientDetails.getSessionDetails().getUserId(), prefs);
		
		return new SimpleResponse(true, "UserPreferences persisted successfully.");
	}
}

==> Gateway-1.6-sources.jar: org/piangles/gateway/requests/processors/UpdateUserPreferencesRequestProcessor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
 
 
 
package org.piangles.gateway.requests.processors;

import java.util.Map;

import org.piangles.backbone.services.Locator;
import org.piangles.backbone.services.prefs.UserPreferences;
import org.piangles.backbone.services.prefs.UserPreferencesService;
import org.piangles.core.util.reflect.TypeToken;
import org.piangles.gateway.client.ClientDetails;
import org.piangles.gateway.requests.Endpoints;
import org.piangles.gateway.requests.dto.Request;
import org.piangles.gateway.requests.dto.SimpleResponse;

public class UpdateUserPreferencesRequestProcessor extends AbstractRequestProcessor<Map<String, Object>, SimpleResponse>
{
	private UserPreferencesService upService = Locator.getInstance().getUserPreferencesService();
	
	public UpdateUserPreferencesRequestProcessor()
	{
		super(Endpoints.UpdateUserPreferences, new TypeToken<Map<String, Object>>() {}.getActualClass(), SimpleResponse.class);
	}
	
	@Override
	protected SimpleResponse processRequest(ClientDetails clientDetails, Request request, Map<String, Object> nvPair) throws Exception
	{
		UserPreferences prefs = new UserPreferences(clientDetails.getSessionDetails().getUserId(), nvPair);
		
		upService.persistUserPreferences(clientDetails.getSessionDetails().getUserId(), prefs);
		
		return new SimpleResponse(true, "UserPreferences persisted successfully.");
	}
}
